@@ -2,6 +2,6 @@ from .client import MoonlistClient
 from .exceptions import *
 from .http import ApiClient
 from .webhook_manager import *
-from moonlistclient import models
-from moonlistclient.models.api import *
-from moonlistclient.models.webhooks import *
\ No newline at end of file
+from . import models
+from .models.api import *
+from .models.webhooks import *
\ No newline at end of file
